==> haskell-authenticate-oauth-1.7-308-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-LmFRteBHgad8gh52iGvyYn
key:                  authenticate-oauth-1.7-LmFRteBHgad8gh52iGvyYn
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  17590c4d11a9c375a127eeb795910bb4
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-LmFRteBHgad8gh52iGvyYn
depends:
    RSA-2.4.1-Hs0BPjEvW2V6xIb8jQoJPB SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    base-4.17.2.1 base64-bytestring-1.2.1.0-3dKpuH5HS82KwnSpVDBu71
    blaze-builder-0.4.3-HXodF8PiFiTI0hprQuztF4 bytestring-0.11.5.3
    crypto-pubkey-types-0.4.3-52kFdQEwRJAZcuRpDoxSb
    data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D
    http-client-0.7.18-IsbH9OAm6XgF9hL4xsUtLO
    http-types-0.12.4-Hz1QXcCML2nIj1GeZ6O8D8
    random-1.2.1.3-FzrwJMuwwLv7643USShEPL time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.7-309-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-CLsf8X1ZKH7Ce7zIG2I0EI
key:                  authenticate-oauth-1.7-CLsf8X1ZKH7Ce7zIG2I0EI
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  b8e53fb54ae4a0563289fdc42ac7c10b
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-CLsf8X1ZKH7Ce7zIG2I0EI
depends:
    RSA-2.4.1-I6mRGA1XhlbFS83rQPrXS9 SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    base-4.17.2.1 base64-bytestring-1.2.1.0-LYBwKrQPWkJ322FRFkSmHQ
    blaze-builder-0.4.3-sOh2upotMIHSy0H3z8bmI bytestring-0.11.5.3
    crypto-pubkey-types-0.4.3-D5UTv6GGcXgIFVP9Pq7O75
    data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D
    http-client-0.7.18-LbIjfqgkVH6EQZrPuBb65p
    http-types-0.12.4-8FTU05okzyoIwQtiG4S4B5
    random-1.2.1.3-K04qxPoOyGIAJkhpqYiZaH time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
